@@ -249,7 +249,7 @@ hd_home_window_class_init (HDHomeWindowClass *window_class)
   pspec = g_param_spec_boolean ("layout-mode-sucks",
                                 "Layout mode sucks",
                                 "Whether or not the layout mode sucks",
-                                TRUE,
+                                FALSE,
                                (G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
   g_object_class_install_property (object_class,
                                    PROP_LAYOUT_MODE_SUCKS,
